pub fn clean(cli: Cli, build_tool_manager: BuildToolManager) -> Result<()>Expand description
Removes generated and downloaded files from code projects to free up space.
Runs in interactive mode unless either one of cli.dry_run and cli.yes is true.